Flask-Dance — Flask Dance 0.4.2 documentation

### Navigation

- index
- modules |
- next |
- Flask Dance 0.4.2 documentation »

# Flask-Dance

Doing the OAuth dance with style using Flask, requests, and oauthlib. Currently, only OAuth consumers are supported, but this project could easily support OAuth providers in the future, as well.

Contents:

- Quickstart
- Pre-set Configurations
  - Github
  - Google
  - Twitter
  - JIRA
- Other Providers
- Token Storage
  - SQLAlchemy
  - Custom Storage
- Signals
  - Core Signals
- API
  - Consumers
  - Models

# Indices and tables

- Index
- Module Index
- Search Page